@@ -175,14 +175,16 @@ class MNAEquationStack:
 
         return np.array(vec)
 
-    def evaluate(self, v_i: np.ndarray, dt: float) -> np.ndarray:
+    def evaluate(self, v_i: np.ndarray, t1: float, t2: float) -> np.ndarray:
         """
         Evaluates the equation stack.
 
         :param v_i:
             The voltages (measured in Volts) and branch consecutive currents (measured in Ampere) as input.
-        :param dt:
-            The time step (measured in seconds).
+        :param t1:
+            Previous point in time (measured in seconds).
+        :param t2:
+            Present point in time (measured in seconds).
         :return:
             The result.
         """
@@ -195,7 +197,8 @@ class MNAEquationStack:
                 if isinstance(term, KirchhoffEquationTerm):
                     summation += (-1 if term.negative else 1) * term.branch.get_current(
                         self._create_coupled_v_i_vector(v_i, term.coupled_branches),
-                        dt,
+                        t1,
+                        t2,
                     )
                 elif isinstance(term, KirchhoffEquationBranchConsecutiveTerm):
                     summation += (
@@ -213,7 +216,8 @@ class MNAEquationStack:
             out_vector.append(
                 branch_consecutive_equation.branch.get_voltage(
                     self._create_coupled_v_i_vector(v_i, branch_consecutive_equation.coupled_branches),
-                    dt,
+                    t1,
+                    t2,
                 )
                 + (v_i[self._nodes.index(source)] if source in self._nodes else 0)
                 - (v_i[self._nodes.index(target)] if target in self._nodes else 0)
@@ -221,6 +225,24 @@ class MNAEquationStack:
 
         return np.array(out_vector)
 
+    def get_voltage_between_nodes(self, solution: np.ndarray, source, target):
+        """
+        Returns the voltage between two nodes from a calculated solution.
+
+        :param solution:
+            The solution vector.
+        :param source:
+            The source node.
+        :param target:
+            The target node.
+        :return:
+            The voltage between `source` and `target` nodes.
+        """
+        return (
+            (solution[self._nodes.index(target)] if target in self._nodes else 0) -
+            (solution[self._nodes.index(source)] if source in self._nodes else 0)
+        )
+
     def get_voltage(self, solution: np.ndarray, branch: CurrentBranch):
         """
         Returns the voltage for a given current-branch from a calculated solution.
@@ -236,10 +258,7 @@ class MNAEquationStack:
             The voltage for `branch`.
         """
         source, target = self._graph.get_nodes(branch)
-        return (
-            (solution[self._nodes.index(target)] if target in self._nodes else 0) -
-            (solution[self._nodes.index(source)] if source in self._nodes else 0)
-        )
+        return self.get_voltage_between_nodes(solution, source, target)
 
     def get_current(self, solution: np.ndarray, branch: VoltageBranch):
         """
@@ -304,7 +323,7 @@ class MNAEquationStack:
                     val = (f'branches[{mapped_branches.add(term.branch)}]'
                            f'.get_current(np.array(['
                            f'{",".join(self._create_lambdified_coupled_v_i_vector(term.coupled_branches))}'
-                           f']),dt)')
+                           f']),t1,t2)')
 
                 elif isinstance(term, KirchhoffEquationBranchConsecutiveTerm):
                     val = f'v_i[{self._currents.index(term.branch) + len(self._nodes)}]'
@@ -324,14 +343,14 @@ class MNAEquationStack:
                 f'branches[{mapped_branches.add(equation.branch)}]'
                 f'.get_voltage(np.array(['
                 f'{",".join(self._create_lambdified_coupled_v_i_vector(equation.coupled_branches))}'
-                f']),dt)'
+                f']),t1,t2)'
                 f'{f"+v_i[{self._nodes.index(source)}]" if source in self._nodes else ""}'
                 f'{f"-v_i[{self._nodes.index(target)}]" if target in self._nodes else ""}'
             )
 
         code = [
             'import numpy as np',
-            'def eq(v_i: np.ndarray, dt: float) -> np.ndarray:',
+            'def eq(v_i: np.ndarray, t1: float, t2: float) -> np.ndarray:',
             ' return np.array([',
         ] + [entry + ',' for entry in vector_entries] + [
             ' ])',
@@ -342,14 +361,16 @@ class MNAEquationStack:
         exec(code_object, code_globals)
         return code_globals['eq']
 
-    def jacobian(self, v_i: np.ndarray, dt: float) -> np.ndarray:
+    def jacobian(self, v_i: np.ndarray, t1: float, t2: float) -> np.ndarray:
         """
         Evaluates the Jacobian of the equation stack.
 
         :param v_i:
             The voltages (measured in Volts) and branch consecutive currents (measured in Ampere) as input.
-        :param dt:
-            The time step (measured in seconds).
+        :param t1:
+            Previous point in time (measured in seconds).
+        :param t2:
+            Present point in time (measured in seconds).
         :return:
             The result.
         """
@@ -363,7 +384,8 @@ class MNAEquationStack:
                     jacobi_vector += (-1 if term.negative else 1) * self._expand_jacobi_vector(
                         term.branch.get_jacobian(
                             self._create_coupled_v_i_vector(v_i, term.coupled_branches),
-                            dt,
+                            t1,
+                            t2,
                         ),
                         term.coupled_branches,  # TODO Maybe I should move all this into a function, since I reuse coupled_branches twice.
                     )
@@ -382,7 +404,8 @@ class MNAEquationStack:
             jacobi_vector += self._expand_jacobi_vector(
                 branch_consecutive_equation.branch.get_jacobian(
                     self._create_coupled_v_i_vector(v_i, branch_consecutive_equation.coupled_branches),
-                    dt,
+                    t1,
+                    t2,
                 ),
                 branch_consecutive_equation.coupled_branches,  # TODO Maybe I should move all this into a function, since I reuse coupled_branches twice.
             )
@@ -460,7 +483,7 @@ class MNAEquationStack:
         precalculated_jacobians = [
             (f'branches[{i}].get_jacobian(np.array(['
              f'{",".join(self._create_lambdified_coupled_v_i_vector(self._coupling_dictionary[branch]))}'
-             f']),dt)')
+             f']),t1,t2)')
             for i, branch in enumerate(mapped_branches)
         ]
 
@@ -471,7 +494,7 @@ class MNAEquationStack:
 
         code = [
             f'import numpy as np',
-            f'def jac(v_i: np.ndarray, dt: float) -> np.ndarray:',
+            f'def jac(v_i: np.ndarray, t1: float, t2: float) -> np.ndarray:',
             f' jacobians = [{",".join(precalculated_jacobians)}]',
             f' return np.array([{",".join(jacobi_matrix_rows)}])',
         ]
