@@ -1,4 +1,4 @@
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 
 from .TwoTerminalCurrentComponent import TwoTerminalCurrentComponent
 
@@ -22,18 +22,28 @@ class Inductance(TwoTerminalCurrentComponent):
     """
     value: float
 
-    state_current: float = 0.0
-    state_voltage: float = 0.0
+    state_current: float = field(default=0.0, repr=False)
+    state_voltage: float = field(default=0.0, repr=False)
 
-    def get_current(self, v: float, dt: float) -> float:
+    def get_current(self, v: float, t1: float, t2: float) -> float:
+        dt = t2 - t1
         return self.state_current + (self.state_voltage + v) / (2 * self.value) * dt
 
-    def get_jacobian(self, v: float, dt: float) -> float:
+    def get_jacobian(self, v: float, t1: float, t2: float) -> float:
+        dt = t2 - t1
         return dt / (2 * self.value)
 
-    def update(self, v: float, dt: float):
-        self.state_current = self.get_current(v, dt)
+    def update(self, v: float, t1: float, t2: float):
+        self.state_current = self.get_current(v, t1, t2)
         self.state_voltage = v
 
+    @property
+    def state(self):
+        return self.state_current, self.state_voltage
+
+    @state.setter
+    def state(self, val):
+        self.state_current, self.state_voltage = val
+
 
 L = Inductance
