@@ -13,10 +13,10 @@ class Resistance(TwoTerminalCurrentComponent):
     """
     value: float
 
-    def get_current(self, v: float, dt: float) -> float:
+    def get_current(self, v: float, t1: float, t2: float) -> float:
         return v / self.value
 
-    def get_jacobian(self, v: float, dt: float) -> float:
+    def get_jacobian(self, v: float, t1: float, t2: float) -> float:
         return 1 / self.value
 
 
