@@ -15,8 +15,8 @@ class VoltageSourceDC(TwoTerminalVoltageComponent):
     """
     value: float
 
-    def get_voltage(self, i: float, dt: float) -> float:
+    def get_voltage(self, i: float, t1: float, t2: float) -> float:
         return self.value
 
-    def get_jacobian(self, i: float, dt: float) -> float:
+    def get_jacobian(self, i: float, t1: float, t2: float) -> float:
         return 0
